/**
 * EasyBeans
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GreeterInterceptor.java 2546 2008-02-29 13:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.cxf;

import javax.annotation.PreDestroy;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

/**
 * This class intercepts Business interfaces methods.
 * @author Guillaume Sauthier
 */
public class GreeterInterceptor {

    /**
     * Invocation counter.
     */
    private int counter = 0;

    /**
     * Count the invocations of a bean.
     * @param ic InvocationContext
     * @return proceeded method
     * @throws Exception if something wrong occurs.
     */
    @AroundInvoke
    public Object count(final InvocationContext ic) throws Exception {

        synchronized (this) {
            this.counter++;
            System.out.println("Invoking method '" + ic.getMethod().getName() + "'.");
            System.out.println("Interceptor called " + this.counter + " times.");
            return ic.proceed();
        }
    }

    /**
     * Called before Bean destruction.
     * @param ic InvocationContext
     */
    @PreDestroy
    public void destroy(final InvocationContext ic) {
        System.out.println("PreDestroy called by EasyBeans.");
    }

}
